@@ -4,7 +4,7 @@ Main interface for codepipeline service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_codepipeline import (
         Client,
         CodePipelineClient,
@@ -16,10 +16,8 @@ Usage::
         ListWebhooksPaginator,
     )
 
-    session = boto3.Session()
-
-    client: CodePipelineClient = boto3.client("codepipeline")
-    session_client: CodePipelineClient = session.client("codepipeline")
+    session = Session()
+    client: CodePipelineClient = session.client("codepipeline")
 
     list_action_executions_paginator: ListActionExecutionsPaginator = client.get_paginator("list_action_executions")
     list_action_types_paginator: ListActionTypesPaginator = client.get_paginator("list_action_types")
